__title__ = 'Django REST Framework - Contact'
__version__ = '0.0.2'
__author__ = 'Civil Machines Technologies Private Limited'
__license__ = 'GPLv3'

default_app_config = 'drf_contact.apps.DRFContactConfig'
