# Generated by Django 2.0.7 on 2018-07-06 12:56

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import drfaddons.datatypes


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ContactDetail',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('update_date', drfaddons.datatypes.UnixTimestampField(auto_created=True)),
                ('create_date', drfaddons.datatypes.UnixTimestampField(auto_now_add=True)),
                ('name', models.CharField(max_length=254, verbose_name='Unique UserName')),
                ('email', models.EmailField(max_length=254, null=True, verbose_name='Email Address')),
                ('mobile', models.CharField(max_length=15, null=True, verbose_name='Mobile Number')),
                ('created_by', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Contact Detail',
                'verbose_name_plural': 'Contact Details',
            },
        ),
        migrations.AlterUniqueTogether(
            name='contactdetail',
            unique_together={('created_by', 'name')},
        ),
    ]
